# pydrinker-gcp
![build on github actions](https://github.com/pydrinker/pydrinker-gcp/actions/workflows/test.yml/badge.svg?branch=main)

This is a extension of pydrinker for Google Cloud Provider to make pydrinker consume messages from [GCP Subscribers](https://cloud.google.com/pubsub/docs/subscriber).

To understand more about pydrinker [see org page](https://github.com/pydrinker).
